package DBIx::Class::ProxyTable::AutoCreateTable;
use strict;
use warnings;

sub _get_table {
    die 'This method is vartual';
}
1;

__END__

=head1 NAME

DBIx::Class::ProxyTable::AutoCreateTable - auto create table base module

=head1 METHOD

=head2 _get_table

    vartual method.
